@@ -6,14 +6,14 @@ now = f'{n.year}{n.month}{n.day}'
 
 apimain = "https://open.neis.go.kr/hub/mealServiceDietInfo" #오픈 api요청주소
 
-async def lunchinfo(param, ATPT_OFCDC_SC_CODE=None, SD_SCHUL_CODE=None, 
-MMEAL_SC_CODE=None, MLSV_YMD=now, MLSV_FROM_YMD=None, MLSV_TO_YMD=None) :
+async def lunchinfo(param, ATPT_OFCDC_SC_CODE=None, SD_SCHUL_CODE=None,
+MMEAL_SC_CODE=None, MLSV_YMD=now, MLSV_FROM_YMD=None, MLSV_TO_YMD=None):
     """
     ``param``은 필수인자입니다.
 
-    ``ATPT_OFCDC_SC_CODE``은 시도교육청코드를 받습니다.
+    ``ATPT_OFCDC_SC_CODE``은 시도교육청코드를 받습니다.(필수)
 
-    ``SD_SCHUL_CODE``은 표준학교코드를 받습니다.
+    ``SD_SCHUL_CODE``은 표준학교코드를 받습니다.(필수)
 
     ``MMEAL_SC_CODE``은 식사코드를 받습니다.
 
@@ -54,5 +54,4 @@ MMEAL_SC_CODE=None, MLSV_YMD=now, MLSV_FROM_YMD=None, MLSV_TO_YMD=None) :
     async with aiohttp.ClientSession() as cs:
         async with cs.get(totalparam) as r:
             response = await r.text()
-            return response
-
+            return response
\ No newline at end of file
