@@ -1,8 +1,8 @@
 import json
 
-async def sort_reqarg(KEY, Type="json", pIndex=str(1), pSize=str(100)):
+async def sort_reqarg(KEY='', Type='json', pIndex=str(1), pSize=str(100)):
     """
-    ``KEY``는 Open APi키를 필요로합니다.
+    ``KEY``는 Open APi키를 필요로합니다. 없을경우 샘플키로 요청합니다.
 
     ``Type``는 json 또는 xml값을 요청할수있습니다. 기본값은 json입니다.
 
@@ -25,7 +25,7 @@ async def sort_lunchmenu(data):
     json을 정리하여 급식 메뉴만을 ``str``로 반환합니다.
     """
     loaddata = json.loads(data)
-    datalist = loaddata['mealServericeDietInfo']
+    datalist = loaddata['mealServiceDietInfo']
     datadict = datalist[1]
     datalist1 = datadict['row']
     datadict1 = datalist1[0]
@@ -49,11 +49,29 @@ async def sort_schoolcode(data):
     return(SC_CODE, SD_SCHUL_CODE)
 
 async def sort_scdname(data):
+    """
+    json 형식만 받아옵니다.
+
+    json을 정리하여 학사일정명을 ``str``로 반환합니다.
+    """
     loaddata = json.loads(data)
     datalist = loaddata['SchoolSchedule']
     datadict = datalist[1]
     datalist1 = datadict['row']
     datadict1 = datalist1[0]
     result = datadict1['EVENT_NM']
-    return(result)
+    return result
+
+async def sort_timetable(data):
+    """
+    json형식만 받아옵니다.
+
+    json을 정리하여 첫번째 교시부터 순서대로 ``list``로 반환합니다.
+    """
+    loaddata = json.loads(data)
+    datalist = loaddata['elsTimetable']
+    datadict = datalist[1]
+    datalist1 = datadict['row'] 
+    result = [f['ITRT_CNTNT'] for f in datalist1]
+    return result
 
